import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { CheckboxProps } from './Checkbox';
export declare type CheckboxGroupOption = Pick<CheckboxProps, 'metadata' | 'className' | 'id' | 'label' | 'subLabel' | 'disabled'> & Required<Pick<CheckboxProps, 'value'>>;
export declare type CheckboxGroupProps = PropsWithMetadata<{
    /** Applies a class name to the root element */
    className?: string;
    /** The name to apply to every Checkbox in the group. A name is generated if none is specified. */
    name?: string;
    /** Disables every Checkbox in the group */
    disabled?: boolean;
    /** Sets the orientation of the Checkbox group */
    orientation?: 'vertical' | 'horizontal';
    /** Array of options to render as Checkbox components */
    options: CheckboxGroupOption[];
    /** The current selected options value */
    value?: CheckboxGroupOption['value'][];
    /** Gets called each time an option is checked. The only argument of this callback is an
     * array of CheckboxGroupOption.
     */
    onChange?: (option: CheckboxGroupOption[]) => void;
}>;
declare const CheckboxGroup: React.ForwardRefExoticComponent<{
    /** Applies a class name to the root element */
    className?: string | undefined;
    /** The name to apply to every Checkbox in the group. A name is generated if none is specified. */
    name?: string | undefined;
    /** Disables every Checkbox in the group */
    disabled?: boolean | undefined;
    /** Sets the orientation of the Checkbox group */
    orientation?: "vertical" | "horizontal" | undefined;
    /** Array of options to render as Checkbox components */
    options: CheckboxGroupOption[];
    /** The current selected options value */
    value?: (string | number | readonly string[])[] | undefined;
    /** Gets called each time an option is checked. The only argument of this callback is an
     * array of CheckboxGroupOption.
     */
    onChange?: ((option: CheckboxGroupOption[]) => void) | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & React.RefAttributes<HTMLDivElement>>;
export default CheckboxGroup;
